=======
Credits
=======

Core team
---------


* Wai Yi Anthony Leung <anthony@askanna.io>
* Robbert Bos <robbert@askanna.io>
* Antonis Sgouros <antonis@askanna.io>

Contributors
------------

Your name here? Open a ticket and start adding features to AskAnna!
